{% load i18n cms_tags %}<{{ instance.tag_type }} {{ instance.attributes_str }}>{% if instance.tag_type == 'pre' %}<code>{% endif %}{{ instance.code_content }}{% if instance.tag_type == 'pre' %}</code>{% endif %}</{{ instance.tag_type }}>
