{% load cms_tags %}

<{{ instance.tag_type }} {{ instance.attributes_str }}
    id="trigger-{{ instance.identifier }}"
    role="tab"
    data-toggle="collapse"
    data-target="#container-{{ instance.identifier }}"
    aria-controls="container-{{ instance.identifier }}"
    aria-expanded="false"
>
    {% for plugin in instance.child_plugin_instances %}
        {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
    {% endfor %}
</{{ instance.tag_type }}>
