{% extends "djangocms_bootstrap4/admin/base.html" %}
{% load static %}

{% block extrahead %}
    {{ block.super }}
    <script src="{% static 'djangocms_bootstrap4/js/bundle.grid.js' %}"></script>
{% endblock %}

{% block field_sets %}
    <div class="djangocms-bootstrap4 djangocms-bootstrap4-row" data-static="{% get_static_prefix %}">
        {{ block.super }}
    </div>
{% endblock %}
