webpackJsonp([0],{90:function(e,s,t){"use strict";Object.defineProperty(s,"__esModule",{value:!0});var a=t(5),i=t.n(a),c=t(18);i()(function(){if(i()(".djangocms-bootstrap4-spacing").length){var e=i()(".djangocms-bootstrap4-spacing").data().static;new c.a({static:e,select:"#id_space_property"}),new c.a({static:e,select:"#id_space_sides"}),new c.a({static:e,select:"#id_space_size"}),new c.a({static:e,select:"#id_space_device",icons:["align-reset","size-xs","size-sm","size-md","size-lg","size-xl"]})}})}},[90]);