{% load cms_tags %}

<{{ instance.tag_type }} {{ instance.attributes_str }}
    id="parent-{{ instance.pk }}"
    data-children="{{ instance.siblings }}"
    role="tablist"
>
    {% with parent=instance %}
        {% for plugin in instance.child_plugin_instances %}
            {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
        {% endfor %}
    {% endwith %}
</{{ instance.tag_type }}>
