{% extends "djangocms_bootstrap4/admin/base.html" %}
{% load i18n %}

{% block custom_class %}djangocms-bootstrap4-media{% endblock %}
{% block custom_message %}
    <p class="alert alert-info">
        {% trans "There is no configuration required here." %}
    </p>
{% endblock %}
