# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _


LISTGROUP_STATE_CHOICES = (
    ('active', _('Active')),
    ('disabled', _('Disabled')),
)
